==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QWindowStateChangeEvent_shell.cpp <==
#include "QWindowStateChangeEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QWindowStateChangeEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWindowStateChangeEvent")
    QWindowStateChangeEvent *_ptr = reinterpret_cast<QWindowStateChangeEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QWindowStateChangeEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QWindowStateChangeEvent_shell) ); }

jmethodID QWindowStateChangeEvent_shell::__shell_javaMethod(int pos) const { return QWindowStateChangeEvent_shell::__shell()->javaMethod(typeid(QWindowStateChangeEvent), pos); }

// emitting (writeShellConstructor)
QWindowStateChangeEvent_shell::QWindowStateChangeEvent_shell(Qt::WindowStates aOldState0, bool isOverride1)
    : QWindowStateChangeEvent(aOldState0, isOverride1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QWindowStateChangeEvent::QWindowStateChangeEvent_shell(Qt::WindowStates aOldState0, bool isOverride1)", QWindowStateChangeEvent_shell::__shell())
    QWindowStateChangeEvent_shell::__shell()->constructed(typeid(QWindowStateChangeEvent));
}

// emitting (writeShellDestructor)
QWindowStateChangeEvent_shell::~QWindowStateChangeEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QWindowStateChangeEvent::~QWindowStateChangeEvent()", QWindowStateChangeEvent_shell::__shell())
    QWindowStateChangeEvent_shell::__shell()->destructed(typeid(QWindowStateChangeEvent));
}

void QWindowStateChangeEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QWindowStateChangeEvent_shell*>(ptr)->QWindowStateChangeEvent_shell::__shell()->tryDeleteShell(typeid(QWindowStateChangeEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QWindowStateChangeEvent(Qt::WindowStates,bool)
void __qt_construct_QWindowStateChangeEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWindowStateChangeEvent(Qt::WindowStates,bool)")
    jobject aOldState0 = __java_arguments[0].l;
    Qt::WindowStates __qt_aOldState0 = qtjambi_cast<Qt::WindowStates>(__jni_env, aOldState0);
    QWindowStateChangeEvent *__qt_this = new(__qtjambi_ptr) QWindowStateChangeEvent_shell(Qt::WindowStates(__qt_aOldState0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QWindowStateChangeEvent(Qt::WindowStates,bool)
void __qt_construct_QWindowStateChangeEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWindowStateChangeEvent(Qt::WindowStates,bool)")
    jobject aOldState0 = __java_arguments[0].l;
    Qt::WindowStates __qt_aOldState0 = qtjambi_cast<Qt::WindowStates>(__jni_env, aOldState0);
    jboolean isOverride1 = __java_arguments[1].z;
    Q_UNUSED(isOverride1)
    QWindowStateChangeEvent *__qt_this = new(__qtjambi_ptr) QWindowStateChangeEvent_shell(Qt::WindowStates(__qt_aOldState0), static_cast<bool>(isOverride1));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QWindowStateChangeEvent_shell
void __qt_destruct_QWindowStateChangeEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWindowStateChangeEvent")
    reinterpret_cast<QWindowStateChangeEvent_shell*>(ptr)->~QWindowStateChangeEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWindowStateChangeEvent::QWindowStateChangeEvent(Qt::WindowStates,bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWindowStateChangeEvent_initialize_1native__Lio_qt_gui_QWindowStateChangeEvent_2Lio_qt_core_Qt_00024WindowStates_2Z)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject aOldState0,
 jboolean isOverride1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWindowStateChangeEvent::QWindowStateChangeEvent(Qt::WindowStates,bool)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = aOldState0;
        arguments[1].z = isOverride1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWindowStateChangeEvent_1, sizeof(QWindowStateChangeEvent_shell), typeid(QWindowStateChangeEvent), true, &deleter_QWindowStateChangeEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWindowStateChangeEvent::isOverride()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWindowStateChangeEvent_isOverride_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QWindowStateChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QWindowStateChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWindowStateChangeEvent::isOverride()const", __qt_this)
        __java_return_value = __qt_this->isOverride();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWindowStateChangeEvent::oldState()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWindowStateChangeEvent_oldState_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QWindowStateChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QWindowStateChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWindowStateChangeEvent::oldState()const", __qt_this)
        Qt::WindowStates __qt_return_value = __qt_this->oldState();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWindowStateChangeEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QWindowStateChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QWindowStateChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QWindowStateChangeEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QWindowStateChangeEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QWindowStateChangeEvent>("QWindowStateChangeEvent", "io/qt/gui/QWindowStateChangeEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QWindowStateChangeEvent, {
        ConstructorInfo(&__qt_construct_QWindowStateChangeEvent_0, "Lio/qt/core/Qt$WindowStates;")
       ,ConstructorInfo(&__qt_construct_QWindowStateChangeEvent_1, "Lio/qt/core/Qt$WindowStates;Z")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWindowStateChangeEvent);
    registerSizeOfShell(typeId, sizeof(QWindowStateChangeEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QWindowStateChangeEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QWindowStateChangeEvent_shell.cpp <==
#include "QWindowStateChangeEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QWindowStateChangeEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWindowStateChangeEvent")
    QWindowStateChangeEvent *_ptr = reinterpret_cast<QWindowStateChangeEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QWindowStateChangeEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QWindowStateChangeEvent_shell) ); }

jmethodID QWindowStateChangeEvent_shell::__shell_javaMethod(int pos) const { return QWindowStateChangeEvent_shell::__shell()->javaMethod(typeid(QWindowStateChangeEvent), pos); }

// emitting (writeShellConstructor)
QWindowStateChangeEvent_shell::QWindowStateChangeEvent_shell(const QWindowStateChangeEvent& other0)
    : QWindowStateChangeEvent(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QWindowStateChangeEvent::QWindowStateChangeEvent_shell(const QWindowStateChangeEvent& other0)", QWindowStateChangeEvent_shell::__shell())
    QWindowStateChangeEvent_shell::__shell()->constructed(typeid(QWindowStateChangeEvent));
}

QWindowStateChangeEvent_shell::QWindowStateChangeEvent_shell(Qt::WindowStates aOldState0, bool isOverride1)
    : QWindowStateChangeEvent(aOldState0, isOverride1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QWindowStateChangeEvent::QWindowStateChangeEvent_shell(Qt::WindowStates aOldState0, bool isOverride1)", QWindowStateChangeEvent_shell::__shell())
    QWindowStateChangeEvent_shell::__shell()->constructed(typeid(QWindowStateChangeEvent));
}

// emitting (writeShellDestructor)
QWindowStateChangeEvent_shell::~QWindowStateChangeEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QWindowStateChangeEvent::~QWindowStateChangeEvent()", QWindowStateChangeEvent_shell::__shell())
    QWindowStateChangeEvent_shell::__shell()->destructed(typeid(QWindowStateChangeEvent));
}

void QWindowStateChangeEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QWindowStateChangeEvent_shell*>(ptr)->QWindowStateChangeEvent_shell::__shell()->tryDeleteShell(typeid(QWindowStateChangeEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QWindowStateChangeEvent(QWindowStateChangeEvent)
void __qt_construct_QWindowStateChangeEvent_cref_QWindowStateChangeEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWindowStateChangeEvent(QWindowStateChangeEvent)")
    jobject other0 = __java_arguments[0].l;
    const QWindowStateChangeEvent& __qt_other0 = qtjambi_cast<const QWindowStateChangeEvent& >(__jni_env, other0);
    QWindowStateChangeEvent *__qt_this = new(__qtjambi_ptr) QWindowStateChangeEvent_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QWindowStateChangeEvent::QWindowStateChangeEvent(QWindowStateChangeEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWindowStateChangeEvent_initialize_1native__Lio_qt_gui_QWindowStateChangeEvent_2Lio_qt_gui_QWindowStateChangeEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWindowStateChangeEvent::QWindowStateChangeEvent(QWindowStateChangeEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWindowStateChangeEvent_cref_QWindowStateChangeEvent, sizeof(QWindowStateChangeEvent_shell), typeid(QWindowStateChangeEvent), true, &deleter_QWindowStateChangeEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QWindowStateChangeEvent(Qt::WindowStates,bool)
void __qt_construct_QWindowStateChangeEvent_Qt_WindowStates(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWindowStateChangeEvent(Qt::WindowStates,bool)")
    jobject aOldState0 = __java_arguments[0].l;
    Qt::WindowStates __qt_aOldState0 = qtjambi_cast<Qt::WindowStates>(__jni_env, aOldState0);
    QWindowStateChangeEvent *__qt_this = new(__qtjambi_ptr) QWindowStateChangeEvent_shell(Qt::WindowStates(__qt_aOldState0));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QWindowStateChangeEvent(Qt::WindowStates,bool)
void __qt_construct_QWindowStateChangeEvent_Qt_WindowStates_bool(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWindowStateChangeEvent(Qt::WindowStates,bool)")
    jobject aOldState0 = __java_arguments[0].l;
    Qt::WindowStates __qt_aOldState0 = qtjambi_cast<Qt::WindowStates>(__jni_env, aOldState0);
    jboolean isOverride1 = __java_arguments[1].z;
    Q_UNUSED(isOverride1)
    QWindowStateChangeEvent *__qt_this = new(__qtjambi_ptr) QWindowStateChangeEvent_shell(Qt::WindowStates(__qt_aOldState0), static_cast<bool>(isOverride1));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QWindowStateChangeEvent::QWindowStateChangeEvent(Qt::WindowStates,bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWindowStateChangeEvent_initialize_1native__Lio_qt_gui_QWindowStateChangeEvent_2Lio_qt_core_Qt_00024WindowStates_2Z)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject aOldState0,
 jboolean isOverride1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWindowStateChangeEvent::QWindowStateChangeEvent(Qt::WindowStates,bool)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = aOldState0;
        arguments[1].z = isOverride1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWindowStateChangeEvent_Qt_WindowStates_bool, sizeof(QWindowStateChangeEvent_shell), typeid(QWindowStateChangeEvent), true, &deleter_QWindowStateChangeEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QWindowStateChangeEvent_shell
void __qt_destruct_QWindowStateChangeEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWindowStateChangeEvent")
    reinterpret_cast<QWindowStateChangeEvent_shell*>(ptr)->~QWindowStateChangeEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWindowStateChangeEvent::isOverride()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWindowStateChangeEvent_isOverride_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QWindowStateChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QWindowStateChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWindowStateChangeEvent::isOverride()const", __qt_this)
        __java_return_value = __qt_this->isOverride();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWindowStateChangeEvent::oldState()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWindowStateChangeEvent_oldState_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QWindowStateChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QWindowStateChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWindowStateChangeEvent::oldState()const", __qt_this)
        Qt::WindowStates __qt_return_value = __qt_this->oldState();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWindowStateChangeEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QWindowStateChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QWindowStateChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QWindowStateChangeEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QWindowStateChangeEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QWindowStateChangeEvent>("QWindowStateChangeEvent", "io/qt/gui/QWindowStateChangeEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QWindowStateChangeEvent, {
        ConstructorInfo(&__qt_construct_QWindowStateChangeEvent_cref_QWindowStateChangeEvent, "Lio/qt/gui/QWindowStateChangeEvent;")
       ,ConstructorInfo(&__qt_construct_QWindowStateChangeEvent_Qt_WindowStates, "Lio/qt/core/Qt$WindowStates;")
       ,ConstructorInfo(&__qt_construct_QWindowStateChangeEvent_Qt_WindowStates_bool, "Lio/qt/core/Qt$WindowStates;Z")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWindowStateChangeEvent);
    registerSizeOfShell(typeId, sizeof(QWindowStateChangeEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QWindowStateChangeEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
